define(
//begin v1.x content
({
	widgetLabel: "Groepsgewijze spellingcontrole",
	unfound: "Niet gevonden",
	skip: "Overslaan",
	skipAll: "Alle overslaan",
	toDic: "Toevoegen aan woordenboek",
	suggestions: "Suggesties",
	replace: "Vervangen",
	replaceWith: "Vervangen door",
	replaceAll: "Alle vervangen",
	cancel: "Annuleren",
	msg: "Geen spelfouten gevonden",
	iSkip: "Deze overslaan",
	iSkipAll: "Al deze overslaan",
	iMsg: "Geen spellingsuggesties"
})

//end v1.x content
);
